/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.api;

/**
 * Formats of the Snooker's Event Entity.
 *
 * @author Dmitry Samoshin aka gotty
 */
public enum EventFormat {

    UNKNOWN    ( 0, "Unknown"                     ),
    CUP        ( 1, "Cup"                         ),
    ROUND      ( 2, "Round-robin"                 ),
    ROUND_CUP  ( 3, "Round-robin followed by cup" ),
    PYRAMID    ( 4, "Pyramid"                     );

    private int number;
    private String desc;

    EventFormat(int number, String desc) {
        this.number = number;
        this.desc = desc;
    }

    public int number() {
        return number;
    }

    public String desc() {
        return desc;
    }

    public static EventFormat byNumber(int number) {
        for (EventFormat type : EventFormat.values()) {
            if (type.number() == number)
                return type;
        }
        return EventFormat.UNKNOWN;
    }

}
