/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.cache.assign;

import org.hedgecode.snooker.api.APIException;
import org.hedgecode.snooker.api.Round;
import org.hedgecode.snooker.json.JsonRound;

/**
 * Assigner for Entity fields of {@link Round}.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class RoundAssigner extends CacheIdAssigner<Round> {

    private static RoundAssigner _instance;

    private RoundAssigner() {
    }

    public static RoundAssigner getInstance() {
        if (_instance == null)
            _instance = new RoundAssigner();
        return _instance;
    }

    @Override
    public void assign(Round round) throws APIException {
        JsonRound jsonRound = (JsonRound) round;
        jsonRound.setEvent(
                cacheScore.getCachedEvent(
                        round.eventId()
                )
        );
        jsonRound.setMainEvent(
                cacheScore.getCachedEvent(
                        round.mainEventId()
                )
        );
    }

}
