/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.compare;

import java.util.Comparator;

import org.hedgecode.snooker.api.Ranking;

/**
 * Set of Comparators for {@link Ranking}.
 * 1. Sorting by Player Position {@link PositionComparator};
 * 2. Sorting by Player Earned Money {@link SumComparator}.
 *
 * @author Dmitry Samoshin aka gotty
 */
public enum RankingComparators {

    POSITION ( new PositionComparator() ),
    SUM      ( new SumComparator() );

    private Comparator<Ranking> comparator;

    RankingComparators(Comparator<Ranking> comparator) {
        this.comparator = comparator;
    }

    public Comparator<Ranking> comparator() {
        return comparator;
    }

    static class PositionComparator implements Comparator<Ranking> {

        @Override
        public int compare(Ranking ranking1, Ranking ranking2) {
            return ranking1.position() - ranking2.position();
        }

    }

    static class SumComparator implements Comparator<Ranking> {

        @Override
        public int compare(Ranking ranking1, Ranking ranking2) {
            return ranking1.sum() < ranking2.sum()
                    ? 1 : ranking1.sum() > ranking2.sum()? -1 : 0;
        }

    }

}
