/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.request;

/**
 * Requester of Rounds Info for an Event.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class EventRoundsRequester extends AbstractRequester {

    private static final String EVENT_ROUNDS_URL = API_SNOOKER_URL + "?t=12&e=[EventID]";

    private static final Requester _instance = new EventRoundsRequester();

    private EventRoundsRequester() {
    }

    public static Requester getInstance() {
        return _instance;
    }

    @Override
    protected String getRequestUrl(int id) throws RequestException {
        if (!isCorrectId(id))
            throw new RequestException(EVENT_ROUNDS_URL, "Incorrect Event ID");

        return EVENT_ROUNDS_URL.replace(
                "[EventID]", String.valueOf(id)
        );
    }

    @Override
    protected String getRequestUrl(RequestParams params) throws RequestException {
        if (params == null || !isCorrectId(params.getEventId()))
            throw new RequestException(EVENT_ROUNDS_URL, "Incorrect Event ID");

        return EVENT_ROUNDS_URL.replace(
                "[EventID]", String.valueOf(params.getEventId())
        );
    }

}
