/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.request;

import org.hedgecode.snooker.api.Season;

/**
 * Requester of Matches for a Player in a Season.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class PlayerMatchesRequester extends AbstractRequester {

    private static final String PLAYER_MATCHES_URL =
            API_SNOOKER_URL + "?t=8&p=[PlayerID]&s=[Season]";

    private static final Requester _instance = new PlayerMatchesRequester();

    private PlayerMatchesRequester() {
    }

    public static Requester getInstance() {
        return _instance;
    }

    @Override
    protected String getRequestUrl(int id) throws RequestException {
        if (!isCorrectId(id))
            throw new RequestException(PLAYER_MATCHES_URL, "Incorrect Player ID");

        return PLAYER_MATCHES_URL.replace(
                "[PlayerID]", String.valueOf(id)
        ).replace(
                "[Season]", String.valueOf(Season.CURRENT_YEAR)
        );
    }

    @Override
    protected String getRequestUrl(RequestParams params) throws RequestException {
        if (params == null
                || !isCorrectId(params.getPlayerId())
                || params.getSeason() == null)
            throw new RequestException(PLAYER_MATCHES_URL, "Incorrect Player Params");

        return PLAYER_MATCHES_URL.replace(
                "[PlayerID]", String.valueOf(params.getPlayerId())
        ).replace(
                "[Season]", String.valueOf(params.getSeason().getYear())
        );
    }

}
