/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.request;

/**
 * Set of Types to Request.
 *
 * @author Dmitry Samoshin aka gotty
 */
public enum RequestType {

    EVENT           ( EventRequester.getInstance()          ),
    MATCH           ( MatchRequester.getInstance()          ),
    PLAYER          ( PlayerRequester.getInstance()         ),
    SEASON_EVENTS   ( SeasonEventsRequester.getInstance()   ),
    EVENT_MATCHES   ( EventMatchesRequester.getInstance()   ),
    ONGOING_MATCHES ( OngoingMatchesRequester.getInstance() ),
    PLAYER_MATCHES  ( PlayerMatchesRequester.getInstance()  ),
    EVENT_PLAYERS   ( EventPlayersRequester.getInstance()   ),
    SEASON_PLAYERS  ( SeasonPlayersRequester.getInstance()  ),
    RANKING         ( RankingRequester.getInstance()        ),
    EVENT_ROUNDS    ( EventRoundsRequester.getInstance()    ),
    EVENT_SEEDING   ( EventSeedingRequester.getInstance()   );

    private Requester requester;

    RequestType(Requester requester) {
        this.requester = requester;
    }

    public Requester requester() {
        return requester;
    }

    public static String request(RequestType type, int id)
            throws RequestException
    {
        if (type == null)
            throw new RequestException(null, "Incorrect Request Type");
        return type.requester().request(id);
    }

    public static String request(RequestType type, RequestParams params)
            throws RequestException
    {
        if (type == null)
            throw new RequestException(null, "Incorrect Request Type");
        return type.requester().request(params);
    }

}
