/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.json;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

/**
 * Tests for {@link JsonEvent}.
 *
 * @author Dmitry Samoshin aka gotty
 */
@RunWith(JUnit4.class)
public class JsonEventTest extends AbstractJsonTest {

    @Test
    public void testEvent() throws Exception {
        JsonEvent[] jsonEvents = GSON.fromJson(
                JsonStringToken.token(
                        jsonFromFile()
                ),
                JsonEvent[].class
        );
        verifySerialize(jsonEvents[0]);
        JsonEvent expectedEvent = (JsonEvent) deserialize();
        assertNull(
                expectedEvent,
                jsonEvents
        );
        JsonEvent actualEvent = jsonEvents[0];
        assertEquals(
                expectedEvent,
                actualEvent
        );
    }

    public static void assertEquals(JsonEvent expected, JsonEvent actual) {
        assertEquals(expected.eventId(), actual.eventId());
        assertEquals(expected.name(), actual.name());
        assertEquals(expected.startDate(), actual.startDate());
        assertEquals(expected.endDate(), actual.endDate());
        assertEquals(expected.sponsor(), actual.sponsor());
        assertEquals(expected.season(), actual.season());
        assertEquals(expected.type(), actual.type());
        assertEquals(expected.num(), actual.num());
        assertEquals(expected.venue(), actual.venue());
        assertEquals(expected.city(), actual.city());
        assertEquals(expected.country(), actual.country());
        assertEquals(expected.discipline(), actual.discipline());
        assertEquals(expected.mainEventId(), actual.mainEventId());
        assertEquals(expected.sex(), actual.sex());
        assertEquals(expected.ageGroup(), actual.ageGroup());
        assertEquals(expected.url(), actual.url());
        assertEquals(expected.related(), actual.related());
        assertEquals(expected.stage(), actual.stage());
        assertEquals(expected.valueType(), actual.valueType());
        assertEquals(expected.shortName(), actual.shortName());
        assertEquals(expected.worldSnookerId(), actual.worldSnookerId());
        assertEquals(expected.rankingType(), actual.rankingType());
        assertEquals(expected.eventPredictionId(), actual.eventPredictionId());
        assertEquals(expected.team(), actual.team());
        assertEquals(expected.format(), actual.format());
        assertEquals(expected.formatType(), actual.formatType());
        assertEquals(expected.twitter(), actual.twitter());
        assertEquals(expected.twitterUrl(), actual.twitterUrl());
        assertEquals(expected.hashTag(), actual.hashTag());
        assertEquals(expected.hashTagUrl(), actual.hashTagUrl());
        assertEquals(expected.conversionRate(), actual.conversionRate(), 0.001);
        assertEquals(expected.allRoundsAdded(), actual.allRoundsAdded());
        assertEquals(expected.photoUrls(), actual.photoUrls());
        assertEquals(expected.numCompetitors(), actual.numCompetitors());
        assertEquals(expected.numUpcoming(), actual.numUpcoming());
        assertEquals(expected.numActive(), actual.numActive());
        assertEquals(expected.numResults(), actual.numResults());
        assertEquals(expected.note(), actual.note());
        assertEquals(expected.commonNote(), actual.commonNote());
        assertEquals(expected.defendingChampionId(), actual.defendingChampionId());
        assertEquals(expected.previousEditionId(), actual.previousEditionId());
    }

}
