/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.json;

import org.hedgecode.snooker.api.Ranking;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

/**
 * Tests for {@link JsonRankings}.
 *
 * @author Dmitry Samoshin aka gotty
 */
@RunWith(JUnit4.class)
public class JsonRankingsTest extends AbstractJsonTest {

    @Test
    public void testRankings() throws Exception {
        JsonRankings actualRankings = new JsonRankings(
                GSON.fromJson(
                        JsonStringToken.token(
                                jsonFromFile()
                        ),
                        JsonRanking[].class
                )
        );
        verifySerialize(actualRankings);
        JsonRankings expectedRankings = (JsonRankings) deserialize();
        assertEquals(
                expectedRankings,
                actualRankings
        );
    }

    public static void assertEquals(JsonRankings expecteds, JsonRankings actuals) {
        assertEquals(
                expecteds.size(),
                actuals.size()
        );
        for (Ranking expected : expecteds) {
            JsonRankingTest.assertEquals(
                    (JsonRanking) expected,
                    (JsonRanking) actuals.byId(expected.getId())
            );
        }
    }

}
